@@ -2,6 +2,24 @@ import time
 import datetime
 import os
 import sys
+from getkey import getkey
+
+
+def get_user_choice(prompt: str = 'please confirm', choices: list = ['y', 'n']):
+    while(True):
+        if not (prompt.endswith(':') or prompt.endswith(': ')):
+            prompt += ':'
+        print(f'{prompt} -> [{"/".join(choices)}] ', end=''); sys.stdout.flush()
+        key = getkey()
+        print(key, end='')
+        if key in choices:
+            print()
+            break
+        else:
+            print(' invalid input. ')
+            continue
+    return key
+
 
 def print_with_time(string):
     print('[{}] '.format(str(datetime.datetime.now())) + string)
